/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fulltext.impl;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.lucene.document.Field;
import org.apache.lucene.document.Field.Store;
import org.apache.lucene.document.LongField;
import org.apache.lucene.document.StringField;
import org.tinygroup.commons.tools.FileUtil;

/**
 * 索引文件
 * 
 * @author renhui
 * 
 */
public class FileIndexProcessor extends AbstractIndexProcessor<File> {

	/**
	 * 以文件名称作为id索引值
	 */
	public String getId(File indexObject) {

		return indexObject.getName();
	}

	/**
	 * 以文件内容作为索引值
	 */
	public String getContents(File indexObject) {
		return readFileContent(indexObject);
	}

	private String readFileContent(File indexObject) {
		try {
			return FileUtil.readFileContent(indexObject, "UTF-8");
		} catch (Exception e) {
			getLogger().errorMessage("获取索引文件内容错误", e);
		}
		return null;
	}

	public List<Field> getExternFieldList(File indexObject) {
		List<Field> fields = new ArrayList<Field>();
		Field path = new StringField("path", indexObject.getPath(), Store.YES);
		fields.add(path);
		Field modified = new LongField("modified", indexObject.lastModified(),
				Field.Store.NO);
		fields.add(modified);
		return fields;
	}

}
