/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.fulltext.impl;

import java.io.IOException;
import java.util.List;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.document.Field.Store;
import org.apache.lucene.document.TextField;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.IndexWriterConfig.OpenMode;
import org.apache.lucene.index.Term;
import org.tinygroup.fulltext.IndexProcessor;
import org.tinygroup.fulltext.IndexProcessorWrapper;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;

/**
 * 索引处理过程接口实现类
 * 
 * @author renhui
 * 
 * @param <T>
 */
public class IndexProcessorWapperImpl<T> implements IndexProcessorWrapper<T> {

	private IndexWriter indexWriter;
	private static Logger logger = LoggerFactory
			.getLogger(IndexProcessorWapperImpl.class);

	public IndexWriter getIndexWriter() {
		return indexWriter;
	}

	public void setIndexWriter(IndexWriter indexWriter) {
		this.indexWriter = indexWriter;
	}

	public void index(IndexProcessor<T> processor, T object) {

		Document doc = new Document();
		String idValue = processor.getId(object);
		Field idField = new TextField("id", idValue, Store.YES);
		doc.add(idField);
		String contentsValue = processor.getContents(object);
		Field contentsField = new TextField("contents", contentsValue,
				Store.YES);
		doc.add(contentsField);
		List<Field> externFieldList = processor.getExternFieldList(object);
		if (externFieldList != null && externFieldList.size() > 0) {
			for (Field externField : externFieldList) {
				doc.add(externField);
			}
		}
		try {
			if (indexWriter.getConfig().getOpenMode() == OpenMode.CREATE) {
				indexWriter.addDocument(doc);
			} else {
				indexWriter.updateDocument(new Term("id", idValue), doc);
			}
			indexWriter.commit();
		} catch (IOException e) {
			logger.error(e);
		}

	}

}
